SimCard class

Constructors

SimCard({String? carrierName, String? displayName, int? slotIndex, String? number, String? countryIso, String? countryPhonePrefix})
SimCard.fromMap(Map<String, dynamic> json)
factory

Properties

carrierName → String?
final
countryIso → String?
final
countryPhonePrefix → String?
final
displayName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
number → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotIndex → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseSimCards(String str) → List<SimCard>
simCardToJson(List<SimCard> data) → String